@@ -5,10 +5,10 @@ import random, string, uuid
 import base64
 class login:
     ak=str(uuid.getnode())
-    ake=k.encode('utf-8')
-    aey=hashlib.sha256(ke)
+    ake=ak.encode('utf-8')
+    aey=hashlib.sha256(ake)
     global key
-    akey=ey.hexdigest()
+    akey=aey.hexdigest()
     k=akey
     ke=k.encode('utf-8')
     ey=hashlib.md5(ke)
@@ -19,12 +19,7 @@ class login:
             text=''
         else:
             pass
-        finger=uuid.getnode()
-        f=str(finger)
-        fi=f.encode('utf-8')
-        fin=hashlib.sha256(fi)
-        finger=fin.hexdigest()
-        print(text+finger)
+        print(akey)
     def auth(auth_id):
         if auth_id=='':
             print('Please Enter auth_id')
